# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.activity import Activity

class TestActivity(unittest.TestCase):
    """Activity unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Activity:
        """Test Activity
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Activity`
        """
        model = Activity()
        if include_optional:
            return Activity(
                content_details = youtube_ti.models.activity_content_details.ActivityContentDetails(
                    bulletin = youtube_ti.models.activity_content_details_bulletin.ActivityContentDetailsBulletin(
                        resource_id = youtube_ti.models.resource_id.ResourceId(
                            channel_id = '', 
                            kind = '', 
                            playlist_id = '', 
                            video_id = '', ), ), 
                    channel_item = youtube_ti.models.activity_content_details_channel_item.ActivityContentDetailsChannelItem(), 
                    comment = youtube_ti.models.activity_content_details_comment.ActivityContentDetailsComment(), 
                    favorite = youtube_ti.models.activity_content_details_favorite.ActivityContentDetailsFavorite(), 
                    like = youtube_ti.models.activity_content_details_like.ActivityContentDetailsLike(), 
                    playlist_item = youtube_ti.models.activity_content_details_playlist_item.ActivityContentDetailsPlaylistItem(
                        playlist_id = '', 
                        playlist_item_id = '', ), 
                    promoted_item = youtube_ti.models.activity_content_details_promoted_item.ActivityContentDetailsPromotedItem(
                        ad_tag = '', 
                        click_tracking_url = '', 
                        creative_view_url = '', 
                        cta_type = 'ctaTypeUnspecified', 
                        custom_cta_button_text = '', 
                        description_text = '', 
                        destination_url = '', 
                        forecasting_url = [
                            ''
                            ], 
                        impression_url = [
                            ''
                            ], 
                        video_id = '', ), 
                    recommendation = youtube_ti.models.activity_content_details_recommendation.ActivityContentDetailsRecommendation(
                        reason = 'reasonUnspecified', 
                        seed_resource_id = youtube_ti.models.resource_id.ResourceId(
                            channel_id = '', 
                            kind = '', 
                            playlist_id = '', 
                            video_id = '', ), ), 
                    social = youtube_ti.models.activity_content_details_social.ActivityContentDetailsSocial(
                        author = '', 
                        image_url = '', 
                        reference_url = '', 
                        type = 'unspecified', ), 
                    subscription = youtube_ti.models.activity_content_details_subscription.ActivityContentDetailsSubscription(), 
                    upload = youtube_ti.models.activity_content_details_upload.ActivityContentDetailsUpload(
                        video_id = '', ), ),
                etag = '',
                id = '',
                kind = 'youtube#activity',
                snippet = youtube_ti.models.activity_snippet.ActivitySnippet(
                    channel_id = '', 
                    channel_title = '', 
                    description = '', 
                    group_id = '', 
                    published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    thumbnails = youtube_ti.models.thumbnail_details.ThumbnailDetails(
                        default = youtube_ti.models.thumbnail.Thumbnail(
                            height = 56, 
                            url = '', 
                            width = 56, ), 
                        high = youtube_ti.models.thumbnail.Thumbnail(
                            height = 56, 
                            url = '', 
                            width = 56, ), 
                        maxres = , 
                        medium = , 
                        standard = , ), 
                    title = '', 
                    type = 'typeUnspecified', )
            )
        else:
            return Activity(
        )
        """

    def testActivity(self):
        """Test Activity"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
