# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.live_stream_status import LiveStreamStatus

class TestLiveStreamStatus(unittest.TestCase):
    """LiveStreamStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LiveStreamStatus:
        """Test LiveStreamStatus
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LiveStreamStatus`
        """
        model = LiveStreamStatus()
        if include_optional:
            return LiveStreamStatus(
                health_status = youtube_ti.models.live_stream_health_status.LiveStreamHealthStatus(
                    configuration_issues = [
                        youtube_ti.models.live_stream_configuration_issue.LiveStreamConfigurationIssue(
                            description = '', 
                            reason = '', 
                            severity = 'info', 
                            type = 'gopSizeOver', )
                        ], 
                    last_update_time_seconds = '', 
                    status = 'good', ),
                stream_status = 'created'
            )
        else:
            return LiveStreamStatus(
        )
        """

    def testLiveStreamStatus(self):
        """Test LiveStreamStatus"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
