# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.search_result_snippet import SearchResultSnippet

class TestSearchResultSnippet(unittest.TestCase):
    """SearchResultSnippet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchResultSnippet:
        """Test SearchResultSnippet
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchResultSnippet`
        """
        model = SearchResultSnippet()
        if include_optional:
            return SearchResultSnippet(
                channel_id = '',
                channel_title = '',
                description = '',
                live_broadcast_content = 'none',
                published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                thumbnails = youtube_ti.models.thumbnail_details.ThumbnailDetails(
                    default = youtube_ti.models.thumbnail.Thumbnail(
                        height = 56, 
                        url = '', 
                        width = 56, ), 
                    high = youtube_ti.models.thumbnail.Thumbnail(
                        height = 56, 
                        url = '', 
                        width = 56, ), 
                    maxres = , 
                    medium = , 
                    standard = , ),
                title = ''
            )
        else:
            return SearchResultSnippet(
        )
        """

    def testSearchResultSnippet(self):
        """Test SearchResultSnippet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
