# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.channel_settings import ChannelSettings

class TestChannelSettings(unittest.TestCase):
    """ChannelSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChannelSettings:
        """Test ChannelSettings
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChannelSettings`
        """
        model = ChannelSettings()
        if include_optional:
            return ChannelSettings(
                country = '',
                default_language = '',
                default_tab = '',
                description = '',
                featured_channels_title = '',
                featured_channels_urls = [
                    ''
                    ],
                keywords = '',
                moderate_comments = True,
                profile_color = '',
                show_browse_view = True,
                show_related_channels = True,
                title = '',
                tracking_analytics_account_id = '',
                unsubscribed_trailer = ''
            )
        else:
            return ChannelSettings(
        )
        """

    def testChannelSettings(self):
        """Test ChannelSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
