# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.channel_section import ChannelSection

class TestChannelSection(unittest.TestCase):
    """ChannelSection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChannelSection:
        """Test ChannelSection
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChannelSection`
        """
        model = ChannelSection()
        if include_optional:
            return ChannelSection(
                content_details = youtube_ti.models.channel_section_content_details.ChannelSectionContentDetails(
                    channels = [
                        ''
                        ], 
                    playlists = [
                        ''
                        ], ),
                etag = '',
                id = '',
                kind = 'youtube#channelSection',
                localizations = None,
                snippet = youtube_ti.models.channel_section_snippet.ChannelSectionSnippet(
                    channel_id = '', 
                    default_language = '', 
                    localized = youtube_ti.models.channel_section_localization.ChannelSectionLocalization(
                        title = '', ), 
                    position = 56, 
                    style = 'channelsectionStyleUnspecified', 
                    title = '', 
                    type = 'channelsectionTypeUndefined', ),
                targeting = youtube_ti.models.channel_section_targeting.ChannelSectionTargeting(
                    countries = [
                        ''
                        ], 
                    languages = [
                        ''
                        ], 
                    regions = [
                        ''
                        ], )
            )
        else:
            return ChannelSection(
        )
        """

    def testChannelSection(self):
        """Test ChannelSection"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
