# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.channel_list_response import ChannelListResponse

class TestChannelListResponse(unittest.TestCase):
    """ChannelListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChannelListResponse:
        """Test ChannelListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChannelListResponse`
        """
        model = ChannelListResponse()
        if include_optional:
            return ChannelListResponse(
                etag = '',
                event_id = '',
                items = [
                    youtube_ti.models.channel.Channel(
                        audit_details = youtube_ti.models.channel_audit_details.ChannelAuditDetails(
                            community_guidelines_good_standing = True, 
                            content_id_claims_good_standing = True, 
                            copyright_strikes_good_standing = True, ), 
                        branding_settings = youtube_ti.models.channel_branding_settings.ChannelBrandingSettings(
                            channel = youtube_ti.models.channel_settings.ChannelSettings(
                                country = '', 
                                default_language = '', 
                                default_tab = '', 
                                description = '', 
                                featured_channels_title = '', 
                                featured_channels_urls = [
                                    ''
                                    ], 
                                keywords = '', 
                                moderate_comments = True, 
                                profile_color = '', 
                                show_browse_view = True, 
                                show_related_channels = True, 
                                title = '', 
                                tracking_analytics_account_id = '', 
                                unsubscribed_trailer = '', ), 
                            hints = [
                                youtube_ti.models.property_value.PropertyValue(
                                    property = '', 
                                    value = '', )
                                ], 
                            image = youtube_ti.models.image_settings.ImageSettings(
                                background_image_url = youtube_ti.models.localized_property.LocalizedProperty(
                                    default = '', 
                                    default_language = youtube_ti.models.language_tag.LanguageTag(
                                        value = '', ), 
                                    localized = [
                                        youtube_ti.models.localized_string.LocalizedString(
                                            language = '', 
                                            value = '', )
                                        ], ), 
                                banner_external_url = '', 
                                banner_image_url = '', 
                                banner_mobile_extra_hd_image_url = '', 
                                banner_mobile_hd_image_url = '', 
                                banner_mobile_image_url = '', 
                                banner_mobile_low_image_url = '', 
                                banner_mobile_medium_hd_image_url = '', 
                                banner_tablet_extra_hd_image_url = '', 
                                banner_tablet_hd_image_url = '', 
                                banner_tablet_image_url = '', 
                                banner_tablet_low_image_url = '', 
                                banner_tv_high_image_url = '', 
                                banner_tv_image_url = '', 
                                banner_tv_low_image_url = '', 
                                banner_tv_medium_image_url = '', 
                                large_branded_banner_image_imap_script = youtube_ti.models.localized_property.LocalizedProperty(
                                    default = '', ), 
                                large_branded_banner_image_url = , 
                                small_branded_banner_image_imap_script = , 
                                small_branded_banner_image_url = , 
                                tracking_image_url = '', 
                                watch_icon_image_url = '', ), 
                            watch = youtube_ti.models.watch_settings.WatchSettings(
                                background_color = '', 
                                featured_playlist_id = '', 
                                text_color = '', ), ), 
                        content_details = youtube_ti.models.channel_content_details.ChannelContentDetails(
                            related_playlists = youtube_ti.models.channel_content_details_related_playlists.ChannelContentDetails_relatedPlaylists(
                                favorites = '', 
                                likes = '', 
                                uploads = '', 
                                watch_history = '', 
                                watch_later = '', ), ), 
                        content_owner_details = youtube_ti.models.channel_content_owner_details.ChannelContentOwnerDetails(
                            content_owner = '', 
                            time_linked = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        conversion_pings = youtube_ti.models.channel_conversion_pings.ChannelConversionPings(
                            pings = [
                                youtube_ti.models.channel_conversion_ping.ChannelConversionPing(
                                    context = 'subscribe', 
                                    conversion_url = '', )
                                ], ), 
                        etag = '', 
                        id = '', 
                        kind = 'youtube#channel', 
                        localizations = youtube_ti.models.localizations.localizations(), 
                        snippet = youtube_ti.models.channel_snippet.ChannelSnippet(
                            country = '', 
                            custom_url = '', 
                            description = '', 
                            published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            thumbnails = youtube_ti.models.thumbnail_details.ThumbnailDetails(
                                default = youtube_ti.models.thumbnail.Thumbnail(
                                    height = 56, 
                                    url = '', 
                                    width = 56, ), 
                                high = youtube_ti.models.thumbnail.Thumbnail(
                                    height = 56, 
                                    url = '', 
                                    width = 56, ), 
                                maxres = , 
                                medium = , 
                                standard = , ), 
                            title = '', ), 
                        statistics = youtube_ti.models.channel_statistics.ChannelStatistics(
                            comment_count = '', 
                            hidden_subscriber_count = True, 
                            subscriber_count = '', 
                            video_count = '', 
                            view_count = '', ), 
                        status = youtube_ti.models.channel_status.ChannelStatus(
                            is_channel_monetization_enabled = True, 
                            is_linked = True, 
                            long_uploads_status = 'longUploadsUnspecified', 
                            made_for_kids = True, 
                            privacy_status = 'public', 
                            self_declared_made_for_kids = True, ), 
                        topic_details = youtube_ti.models.channel_topic_details.ChannelTopicDetails(
                            topic_categories = [
                                ''
                                ], 
                            topic_ids = [
                                ''
                                ], ), )
                    ],
                kind = 'youtube#channelListResponse',
                next_page_token = '',
                page_info = youtube_ti.models.page_info.PageInfo(
                    results_per_page = 56, 
                    total_results = 56, ),
                prev_page_token = '',
                token_pagination = None,
                visitor_id = ''
            )
        else:
            return ChannelListResponse(
        )
        """

    def testChannelListResponse(self):
        """Test ChannelListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
