# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.memberships_level_list_response import MembershipsLevelListResponse

class TestMembershipsLevelListResponse(unittest.TestCase):
    """MembershipsLevelListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MembershipsLevelListResponse:
        """Test MembershipsLevelListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MembershipsLevelListResponse`
        """
        model = MembershipsLevelListResponse()
        if include_optional:
            return MembershipsLevelListResponse(
                etag = '',
                event_id = '',
                items = [
                    youtube_ti.models.memberships_level.MembershipsLevel(
                        etag = '', 
                        id = '', 
                        kind = 'youtube#membershipsLevel', 
                        snippet = youtube_ti.models.memberships_level_snippet.MembershipsLevelSnippet(
                            creator_channel_id = '', 
                            level_details = youtube_ti.models.level_details.LevelDetails(
                                display_name = '', ), ), )
                    ],
                kind = 'youtube#membershipsLevelListResponse',
                visitor_id = ''
            )
        else:
            return MembershipsLevelListResponse(
        )
        """

    def testMembershipsLevelListResponse(self):
        """Test MembershipsLevelListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
