# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.playlist_image_list_response import PlaylistImageListResponse

class TestPlaylistImageListResponse(unittest.TestCase):
    """PlaylistImageListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PlaylistImageListResponse:
        """Test PlaylistImageListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PlaylistImageListResponse`
        """
        model = PlaylistImageListResponse()
        if include_optional:
            return PlaylistImageListResponse(
                items = [
                    youtube_ti.models.playlist_image.PlaylistImage(
                        id = '', 
                        kind = 'youtube#playlistImage', 
                        snippet = youtube_ti.models.playlist_image_snippet.PlaylistImageSnippet(
                            height = 56, 
                            playlist_id = '', 
                            type = 'hero', 
                            width = 56, ), )
                    ],
                kind = 'youtube#playlistImageListResponse',
                next_page_token = '',
                page_info = youtube_ti.models.page_info.PageInfo(
                    results_per_page = 56, 
                    total_results = 56, ),
                prev_page_token = ''
            )
        else:
            return PlaylistImageListResponse(
        )
        """

    def testPlaylistImageListResponse(self):
        """Test PlaylistImageListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
