# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.live_chat_gift_membership_received_details import LiveChatGiftMembershipReceivedDetails

class TestLiveChatGiftMembershipReceivedDetails(unittest.TestCase):
    """LiveChatGiftMembershipReceivedDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LiveChatGiftMembershipReceivedDetails:
        """Test LiveChatGiftMembershipReceivedDetails
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LiveChatGiftMembershipReceivedDetails`
        """
        model = LiveChatGiftMembershipReceivedDetails()
        if include_optional:
            return LiveChatGiftMembershipReceivedDetails(
                associated_membership_gifting_message_id = '',
                gifter_channel_id = '',
                member_level_name = ''
            )
        else:
            return LiveChatGiftMembershipReceivedDetails(
        )
        """

    def testLiveChatGiftMembershipReceivedDetails(self):
        """Test LiveChatGiftMembershipReceivedDetails"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
