# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.api.live_chat_bans_api import LiveChatBansApi


class TestLiveChatBansApi(unittest.TestCase):
    """LiveChatBansApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LiveChatBansApi()

    def tearDown(self) -> None:
        pass

    def test_youtube_live_chat_bans_delete(self) -> None:
        """Test case for youtube_live_chat_bans_delete

        """
        pass

    def test_youtube_live_chat_bans_insert(self) -> None:
        """Test case for youtube_live_chat_bans_insert

        """
        pass


if __name__ == '__main__':
    unittest.main()
