# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.i18n_region_list_response import I18nRegionListResponse

class TestI18nRegionListResponse(unittest.TestCase):
    """I18nRegionListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> I18nRegionListResponse:
        """Test I18nRegionListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `I18nRegionListResponse`
        """
        model = I18nRegionListResponse()
        if include_optional:
            return I18nRegionListResponse(
                etag = '',
                event_id = '',
                items = [
                    youtube_ti.models.i18n_region.I18nRegion(
                        etag = '', 
                        id = '', 
                        kind = 'youtube#i18nRegion', 
                        snippet = youtube_ti.models.i18n_region_snippet.I18nRegionSnippet(
                            gl = '', 
                            name = '', ), )
                    ],
                kind = 'youtube#i18nRegionListResponse',
                visitor_id = ''
            )
        else:
            return I18nRegionListResponse(
        )
        """

    def testI18nRegionListResponse(self):
        """Test I18nRegionListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
