# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.video_status import VideoStatus

class TestVideoStatus(unittest.TestCase):
    """VideoStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VideoStatus:
        """Test VideoStatus
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VideoStatus`
        """
        model = VideoStatus()
        if include_optional:
            return VideoStatus(
                contains_synthetic_media = True,
                embeddable = True,
                failure_reason = 'conversion',
                license = 'youtube',
                made_for_kids = True,
                privacy_status = 'public',
                public_stats_viewable = True,
                publish_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                rejection_reason = 'copyright',
                self_declared_made_for_kids = True,
                upload_status = 'uploaded'
            )
        else:
            return VideoStatus(
        )
        """

    def testVideoStatus(self):
        """Test VideoStatus"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
