# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.video_file_details import VideoFileDetails

class TestVideoFileDetails(unittest.TestCase):
    """VideoFileDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VideoFileDetails:
        """Test VideoFileDetails
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VideoFileDetails`
        """
        model = VideoFileDetails()
        if include_optional:
            return VideoFileDetails(
                audio_streams = [
                    youtube_ti.models.video_file_details_audio_stream.VideoFileDetailsAudioStream(
                        bitrate_bps = '', 
                        channel_count = 56, 
                        codec = '', 
                        vendor = '', )
                    ],
                bitrate_bps = '',
                container = '',
                creation_time = '',
                duration_ms = '',
                file_name = '',
                file_size = '',
                file_type = 'video',
                video_streams = [
                    youtube_ti.models.video_file_details_video_stream.VideoFileDetailsVideoStream(
                        aspect_ratio = 1.337, 
                        bitrate_bps = '', 
                        codec = '', 
                        frame_rate_fps = 1.337, 
                        height_pixels = 56, 
                        rotation = 'none', 
                        vendor = '', 
                        width_pixels = 56, )
                    ]
            )
        else:
            return VideoFileDetails(
        )
        """

    def testVideoFileDetails(self):
        """Test VideoFileDetails"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
