# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from youtube_ti.models.page_info import PageInfo
from youtube_ti.models.video_category import VideoCategory
from typing import Optional, Set
from typing_extensions import Self

class VideoCategoryListResponse(BaseModel):
    """
    VideoCategoryListResponse
    """ # noqa: E501
    etag: Optional[StrictStr] = Field(default=None, description="Etag of this resource.")
    event_id: Optional[StrictStr] = Field(default=None, description="Serialized EventId of the request which produced this response.", alias="eventId")
    items: Optional[List[VideoCategory]] = Field(default=None, description="A list of video categories that can be associated with YouTube videos. In this map, the video category ID is the map key, and its value is the corresponding videoCategory resource.")
    kind: Optional[StrictStr] = Field(default='youtube#videoCategoryListResponse', description="Identifies what kind of resource this is. Value: the fixed string \"youtube#videoCategoryListResponse\".")
    next_page_token: Optional[StrictStr] = Field(default=None, description="The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.", alias="nextPageToken")
    page_info: Optional[PageInfo] = Field(default=None, alias="pageInfo")
    prev_page_token: Optional[StrictStr] = Field(default=None, description="The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.", alias="prevPageToken")
    token_pagination: Optional[Dict[str, Any]] = Field(default=None, description="Stub token pagination template to suppress results.", alias="tokenPagination")
    visitor_id: Optional[StrictStr] = Field(default=None, description="The visitorId identifies the visitor.", alias="visitorId")
    __properties: ClassVar[List[str]] = ["etag", "eventId", "items", "kind", "nextPageToken", "pageInfo", "prevPageToken", "tokenPagination", "visitorId"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VideoCategoryListResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in items (list)
        _items = []
        if self.items:
            for _item_items in self.items:
                if _item_items:
                    _items.append(_item_items.to_dict())
            _dict['items'] = _items
        # override the default output from pydantic by calling `to_dict()` of page_info
        if self.page_info:
            _dict['pageInfo'] = self.page_info.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VideoCategoryListResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "etag": obj.get("etag"),
            "eventId": obj.get("eventId"),
            "items": [VideoCategory.from_dict(_item) for _item in obj["items"]] if obj.get("items") is not None else None,
            "kind": obj.get("kind") if obj.get("kind") is not None else 'youtube#videoCategoryListResponse',
            "nextPageToken": obj.get("nextPageToken"),
            "pageInfo": PageInfo.from_dict(obj["pageInfo"]) if obj.get("pageInfo") is not None else None,
            "prevPageToken": obj.get("prevPageToken"),
            "tokenPagination": obj.get("tokenPagination"),
            "visitorId": obj.get("visitorId")
        })
        return _obj


