# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class LiveStreamConfigurationIssue(BaseModel):
    """
    LiveStreamConfigurationIssue
    """ # noqa: E501
    description: Optional[StrictStr] = Field(default=None, description="The long-form description of the issue and how to resolve it.")
    reason: Optional[StrictStr] = Field(default=None, description="The short-form reason for this issue.")
    severity: Optional[StrictStr] = Field(default=None, description="How severe this issue is to the stream.")
    type: Optional[StrictStr] = Field(default=None, description="The kind of error happening.")
    __properties: ClassVar[List[str]] = ["description", "reason", "severity", "type"]

    @field_validator('severity')
    def severity_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['info', 'warning', 'error']):
            raise ValueError("must be one of enum values ('info', 'warning', 'error')")
        return value

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['gopSizeOver', 'gopSizeLong', 'gopSizeShort', 'openGop', 'badContainer', 'audioBitrateHigh', 'audioBitrateLow', 'audioSampleRate', 'bitrateHigh', 'bitrateLow', 'audioCodec', 'videoCodec', 'noAudioStream', 'noVideoStream', 'multipleVideoStreams', 'multipleAudioStreams', 'audioTooManyChannels', 'interlacedVideo', 'frameRateHigh', 'resolutionMismatch', 'videoCodecMismatch', 'videoInterlaceMismatch', 'videoProfileMismatch', 'videoBitrateMismatch', 'framerateMismatch', 'gopMismatch', 'audioSampleRateMismatch', 'audioStereoMismatch', 'audioCodecMismatch', 'audioBitrateMismatch', 'videoResolutionSuboptimal', 'videoResolutionUnsupported', 'videoIngestionStarved', 'videoIngestionFasterThanRealtime']):
            raise ValueError("must be one of enum values ('gopSizeOver', 'gopSizeLong', 'gopSizeShort', 'openGop', 'badContainer', 'audioBitrateHigh', 'audioBitrateLow', 'audioSampleRate', 'bitrateHigh', 'bitrateLow', 'audioCodec', 'videoCodec', 'noAudioStream', 'noVideoStream', 'multipleVideoStreams', 'multipleAudioStreams', 'audioTooManyChannels', 'interlacedVideo', 'frameRateHigh', 'resolutionMismatch', 'videoCodecMismatch', 'videoInterlaceMismatch', 'videoProfileMismatch', 'videoBitrateMismatch', 'framerateMismatch', 'gopMismatch', 'audioSampleRateMismatch', 'audioStereoMismatch', 'audioCodecMismatch', 'audioBitrateMismatch', 'videoResolutionSuboptimal', 'videoResolutionUnsupported', 'videoIngestionStarved', 'videoIngestionFasterThanRealtime')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of LiveStreamConfigurationIssue from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of LiveStreamConfigurationIssue from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "description": obj.get("description"),
            "reason": obj.get("reason"),
            "severity": obj.get("severity"),
            "type": obj.get("type")
        })
        return _obj


