# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.caption_list_response import CaptionListResponse

class TestCaptionListResponse(unittest.TestCase):
    """CaptionListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CaptionListResponse:
        """Test CaptionListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CaptionListResponse`
        """
        model = CaptionListResponse()
        if include_optional:
            return CaptionListResponse(
                etag = '',
                event_id = '',
                items = [
                    youtube_ti.models.caption.Caption(
                        etag = '', 
                        id = '', 
                        kind = 'youtube#caption', 
                        snippet = youtube_ti.models.caption_snippet.CaptionSnippet(
                            audio_track_type = 'unknown', 
                            failure_reason = 'unknownFormat', 
                            is_auto_synced = True, 
                            is_cc = True, 
                            is_draft = True, 
                            is_easy_reader = True, 
                            is_large = True, 
                            language = '', 
                            last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            name = '', 
                            status = 'serving', 
                            track_kind = 'standard', 
                            video_id = '', ), )
                    ],
                kind = 'youtube#captionListResponse',
                visitor_id = ''
            )
        else:
            return CaptionListResponse(
        )
        """

    def testCaptionListResponse(self):
        """Test CaptionListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
