# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.super_chat_event_list_response import SuperChatEventListResponse

class TestSuperChatEventListResponse(unittest.TestCase):
    """SuperChatEventListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SuperChatEventListResponse:
        """Test SuperChatEventListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SuperChatEventListResponse`
        """
        model = SuperChatEventListResponse()
        if include_optional:
            return SuperChatEventListResponse(
                etag = '',
                event_id = '',
                items = [
                    youtube_ti.models.super_chat_event.SuperChatEvent(
                        etag = '', 
                        id = '', 
                        kind = 'youtube#superChatEvent', 
                        snippet = youtube_ti.models.super_chat_event_snippet.SuperChatEventSnippet(
                            amount_micros = '', 
                            channel_id = '', 
                            comment_text = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            currency = '', 
                            display_string = '', 
                            is_super_sticker_event = True, 
                            message_type = 56, 
                            super_sticker_metadata = youtube_ti.models.super_sticker_metadata.SuperStickerMetadata(
                                alt_text = '', 
                                alt_text_language = '', 
                                sticker_id = '', ), 
                            supporter_details = youtube_ti.models.channel_profile_details.ChannelProfileDetails(
                                channel_id = '', 
                                channel_url = '', 
                                display_name = '', 
                                profile_image_url = '', ), ), )
                    ],
                kind = 'youtube#superChatEventListResponse',
                next_page_token = '',
                page_info = youtube_ti.models.page_info.PageInfo(
                    results_per_page = 56, 
                    total_results = 56, ),
                token_pagination = None,
                visitor_id = ''
            )
        else:
            return SuperChatEventListResponse(
        )
        """

    def testSuperChatEventListResponse(self):
        """Test SuperChatEventListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
