# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.member import Member

class TestMember(unittest.TestCase):
    """Member unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Member:
        """Test Member
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Member`
        """
        model = Member()
        if include_optional:
            return Member(
                etag = '',
                kind = 'youtube#member',
                snippet = youtube_ti.models.member_snippet.MemberSnippet(
                    creator_channel_id = '', 
                    member_details = youtube_ti.models.channel_profile_details.ChannelProfileDetails(
                        channel_id = '', 
                        channel_url = '', 
                        display_name = '', 
                        profile_image_url = '', ), 
                    memberships_details = youtube_ti.models.memberships_details.MembershipsDetails(
                        accessible_levels = [
                            ''
                            ], 
                        highest_accessible_level = '', 
                        highest_accessible_level_display_name = '', 
                        memberships_duration = youtube_ti.models.memberships_duration.MembershipsDuration(
                            member_since = '', 
                            member_total_duration_months = 56, ), 
                        memberships_duration_at_levels = [
                            youtube_ti.models.memberships_duration_at_level.MembershipsDurationAtLevel(
                                level = '', 
                                member_since = '', 
                                member_total_duration_months = 56, )
                            ], ), )
            )
        else:
            return Member(
        )
        """

    def testMember(self):
        """Test Member"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
