# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.third_party_link_list_response import ThirdPartyLinkListResponse

class TestThirdPartyLinkListResponse(unittest.TestCase):
    """ThirdPartyLinkListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ThirdPartyLinkListResponse:
        """Test ThirdPartyLinkListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ThirdPartyLinkListResponse`
        """
        model = ThirdPartyLinkListResponse()
        if include_optional:
            return ThirdPartyLinkListResponse(
                etag = '',
                items = [
                    youtube_ti.models.third_party_link.ThirdPartyLink(
                        etag = '', 
                        kind = 'youtube#thirdPartyLink', 
                        linking_token = '', 
                        snippet = youtube_ti.models.third_party_link_snippet.ThirdPartyLinkSnippet(
                            channel_to_store_link = youtube_ti.models.channel_to_store_link_details.ChannelToStoreLinkDetails(
                                billing_details = youtube_ti.models.channel_to_store_link_details_billing_details.ChannelToStoreLinkDetailsBillingDetails(
                                    billing_status = 'billingStatusUnspecified', ), 
                                merchant_affiliate_program_details = youtube_ti.models.channel_to_store_link_details_merchant_affiliate_program_details.ChannelToStoreLinkDetailsMerchantAffiliateProgramDetails(
                                    status = 'merchantAffiliateProgramStatusUnspecified', ), 
                                merchant_id = '', 
                                store_name = '', 
                                store_url = '', ), 
                            type = 'linkUnspecified', ), 
                        status = youtube_ti.models.third_party_link_status.ThirdPartyLinkStatus(
                            link_status = 'unknown', ), )
                    ],
                kind = 'youtube#thirdPartyLinkListResponse'
            )
        else:
            return ThirdPartyLinkListResponse(
        )
        """

    def testThirdPartyLinkListResponse(self):
        """Test ThirdPartyLinkListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
