# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.channel_section_snippet import ChannelSectionSnippet

class TestChannelSectionSnippet(unittest.TestCase):
    """ChannelSectionSnippet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChannelSectionSnippet:
        """Test ChannelSectionSnippet
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChannelSectionSnippet`
        """
        model = ChannelSectionSnippet()
        if include_optional:
            return ChannelSectionSnippet(
                channel_id = '',
                default_language = '',
                localized = youtube_ti.models.channel_section_localization.ChannelSectionLocalization(
                    title = '', ),
                position = 56,
                style = 'channelsectionStyleUnspecified',
                title = '',
                type = 'channelsectionTypeUndefined'
            )
        else:
            return ChannelSectionSnippet(
        )
        """

    def testChannelSectionSnippet(self):
        """Test ChannelSectionSnippet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
