# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.live_chat_poll_details import LiveChatPollDetails

class TestLiveChatPollDetails(unittest.TestCase):
    """LiveChatPollDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LiveChatPollDetails:
        """Test LiveChatPollDetails
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LiveChatPollDetails`
        """
        model = LiveChatPollDetails()
        if include_optional:
            return LiveChatPollDetails(
                metadata = youtube_ti.models.live_chat_poll_details_poll_metadata.LiveChatPollDetailsPollMetadata(
                    options = [
                        youtube_ti.models.live_chat_poll_details_poll_metadata_poll_option.LiveChatPollDetailsPollMetadataPollOption(
                            option_text = '', 
                            tally = '', )
                        ], 
                    question_text = '', ),
                status = 'unknown'
            )
        else:
            return LiveChatPollDetails(
        )
        """

    def testLiveChatPollDetails(self):
        """Test LiveChatPollDetails"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
