# coding: utf-8

# flake8: noqa
"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from youtube_ti.models.abuse_report import AbuseReport
from youtube_ti.models.abuse_type import AbuseType
from youtube_ti.models.access_policy import AccessPolicy
from youtube_ti.models.activity import Activity
from youtube_ti.models.activity_content_details import ActivityContentDetails
from youtube_ti.models.activity_content_details_bulletin import ActivityContentDetailsBulletin
from youtube_ti.models.activity_content_details_channel_item import ActivityContentDetailsChannelItem
from youtube_ti.models.activity_content_details_comment import ActivityContentDetailsComment
from youtube_ti.models.activity_content_details_favorite import ActivityContentDetailsFavorite
from youtube_ti.models.activity_content_details_like import ActivityContentDetailsLike
from youtube_ti.models.activity_content_details_playlist_item import ActivityContentDetailsPlaylistItem
from youtube_ti.models.activity_content_details_promoted_item import ActivityContentDetailsPromotedItem
from youtube_ti.models.activity_content_details_recommendation import ActivityContentDetailsRecommendation
from youtube_ti.models.activity_content_details_social import ActivityContentDetailsSocial
from youtube_ti.models.activity_content_details_subscription import ActivityContentDetailsSubscription
from youtube_ti.models.activity_content_details_upload import ActivityContentDetailsUpload
from youtube_ti.models.activity_list_response import ActivityListResponse
from youtube_ti.models.activity_snippet import ActivitySnippet
from youtube_ti.models.caption import Caption
from youtube_ti.models.caption_list_response import CaptionListResponse
from youtube_ti.models.caption_snippet import CaptionSnippet
from youtube_ti.models.cdn_settings import CdnSettings
from youtube_ti.models.channel import Channel
from youtube_ti.models.channel_audit_details import ChannelAuditDetails
from youtube_ti.models.channel_banner_resource import ChannelBannerResource
from youtube_ti.models.channel_branding_settings import ChannelBrandingSettings
from youtube_ti.models.channel_content_details import ChannelContentDetails
from youtube_ti.models.channel_content_details_related_playlists import ChannelContentDetailsRelatedPlaylists
from youtube_ti.models.channel_content_owner_details import ChannelContentOwnerDetails
from youtube_ti.models.channel_conversion_ping import ChannelConversionPing
from youtube_ti.models.channel_conversion_pings import ChannelConversionPings
from youtube_ti.models.channel_list_response import ChannelListResponse
from youtube_ti.models.channel_localization import ChannelLocalization
from youtube_ti.models.channel_profile_details import ChannelProfileDetails
from youtube_ti.models.channel_section import ChannelSection
from youtube_ti.models.channel_section_content_details import ChannelSectionContentDetails
from youtube_ti.models.channel_section_list_response import ChannelSectionListResponse
from youtube_ti.models.channel_section_localization import ChannelSectionLocalization
from youtube_ti.models.channel_section_snippet import ChannelSectionSnippet
from youtube_ti.models.channel_section_targeting import ChannelSectionTargeting
from youtube_ti.models.channel_settings import ChannelSettings
from youtube_ti.models.channel_snippet import ChannelSnippet
from youtube_ti.models.channel_statistics import ChannelStatistics
from youtube_ti.models.channel_status import ChannelStatus
from youtube_ti.models.channel_to_store_link_details import ChannelToStoreLinkDetails
from youtube_ti.models.channel_to_store_link_details_billing_details import ChannelToStoreLinkDetailsBillingDetails
from youtube_ti.models.channel_to_store_link_details_merchant_affiliate_program_details import ChannelToStoreLinkDetailsMerchantAffiliateProgramDetails
from youtube_ti.models.channel_topic_details import ChannelTopicDetails
from youtube_ti.models.comment import Comment
from youtube_ti.models.comment_list_response import CommentListResponse
from youtube_ti.models.comment_snippet import CommentSnippet
from youtube_ti.models.comment_snippet_author_channel_id import CommentSnippetAuthorChannelId
from youtube_ti.models.comment_thread import CommentThread
from youtube_ti.models.comment_thread_list_response import CommentThreadListResponse
from youtube_ti.models.comment_thread_replies import CommentThreadReplies
from youtube_ti.models.comment_thread_snippet import CommentThreadSnippet
from youtube_ti.models.content_rating import ContentRating
from youtube_ti.models.cuepoint import Cuepoint
from youtube_ti.models.cuepoint_schedule import CuepointSchedule
from youtube_ti.models.entity import Entity
from youtube_ti.models.geo_point import GeoPoint
from youtube_ti.models.i18n_language import I18nLanguage
from youtube_ti.models.i18n_language_list_response import I18nLanguageListResponse
from youtube_ti.models.i18n_language_snippet import I18nLanguageSnippet
from youtube_ti.models.i18n_region import I18nRegion
from youtube_ti.models.i18n_region_list_response import I18nRegionListResponse
from youtube_ti.models.i18n_region_snippet import I18nRegionSnippet
from youtube_ti.models.image_settings import ImageSettings
from youtube_ti.models.ingestion_info import IngestionInfo
from youtube_ti.models.invideo_branding import InvideoBranding
from youtube_ti.models.invideo_position import InvideoPosition
from youtube_ti.models.invideo_timing import InvideoTiming
from youtube_ti.models.language_tag import LanguageTag
from youtube_ti.models.level_details import LevelDetails
from youtube_ti.models.live_broadcast import LiveBroadcast
from youtube_ti.models.live_broadcast_content_details import LiveBroadcastContentDetails
from youtube_ti.models.live_broadcast_list_response import LiveBroadcastListResponse
from youtube_ti.models.live_broadcast_monetization_details import LiveBroadcastMonetizationDetails
from youtube_ti.models.live_broadcast_snippet import LiveBroadcastSnippet
from youtube_ti.models.live_broadcast_statistics import LiveBroadcastStatistics
from youtube_ti.models.live_broadcast_status import LiveBroadcastStatus
from youtube_ti.models.live_chat_ban import LiveChatBan
from youtube_ti.models.live_chat_ban_snippet import LiveChatBanSnippet
from youtube_ti.models.live_chat_fan_funding_event_details import LiveChatFanFundingEventDetails
from youtube_ti.models.live_chat_gift_membership_received_details import LiveChatGiftMembershipReceivedDetails
from youtube_ti.models.live_chat_member_milestone_chat_details import LiveChatMemberMilestoneChatDetails
from youtube_ti.models.live_chat_membership_gifting_details import LiveChatMembershipGiftingDetails
from youtube_ti.models.live_chat_message import LiveChatMessage
from youtube_ti.models.live_chat_message_author_details import LiveChatMessageAuthorDetails
from youtube_ti.models.live_chat_message_deleted_details import LiveChatMessageDeletedDetails
from youtube_ti.models.live_chat_message_list_response import LiveChatMessageListResponse
from youtube_ti.models.live_chat_message_retracted_details import LiveChatMessageRetractedDetails
from youtube_ti.models.live_chat_message_snippet import LiveChatMessageSnippet
from youtube_ti.models.live_chat_moderator import LiveChatModerator
from youtube_ti.models.live_chat_moderator_list_response import LiveChatModeratorListResponse
from youtube_ti.models.live_chat_moderator_snippet import LiveChatModeratorSnippet
from youtube_ti.models.live_chat_new_sponsor_details import LiveChatNewSponsorDetails
from youtube_ti.models.live_chat_poll_details import LiveChatPollDetails
from youtube_ti.models.live_chat_poll_details_poll_metadata import LiveChatPollDetailsPollMetadata
from youtube_ti.models.live_chat_poll_details_poll_metadata_poll_option import LiveChatPollDetailsPollMetadataPollOption
from youtube_ti.models.live_chat_super_chat_details import LiveChatSuperChatDetails
from youtube_ti.models.live_chat_super_sticker_details import LiveChatSuperStickerDetails
from youtube_ti.models.live_chat_text_message_details import LiveChatTextMessageDetails
from youtube_ti.models.live_chat_user_banned_message_details import LiveChatUserBannedMessageDetails
from youtube_ti.models.live_stream import LiveStream
from youtube_ti.models.live_stream_configuration_issue import LiveStreamConfigurationIssue
from youtube_ti.models.live_stream_content_details import LiveStreamContentDetails
from youtube_ti.models.live_stream_health_status import LiveStreamHealthStatus
from youtube_ti.models.live_stream_list_response import LiveStreamListResponse
from youtube_ti.models.live_stream_snippet import LiveStreamSnippet
from youtube_ti.models.live_stream_status import LiveStreamStatus
from youtube_ti.models.localized_property import LocalizedProperty
from youtube_ti.models.localized_string import LocalizedString
from youtube_ti.models.member import Member
from youtube_ti.models.member_list_response import MemberListResponse
from youtube_ti.models.member_snippet import MemberSnippet
from youtube_ti.models.memberships_details import MembershipsDetails
from youtube_ti.models.memberships_duration import MembershipsDuration
from youtube_ti.models.memberships_duration_at_level import MembershipsDurationAtLevel
from youtube_ti.models.memberships_level import MembershipsLevel
from youtube_ti.models.memberships_level_list_response import MembershipsLevelListResponse
from youtube_ti.models.memberships_level_snippet import MembershipsLevelSnippet
from youtube_ti.models.monitor_stream_info import MonitorStreamInfo
from youtube_ti.models.page_info import PageInfo
from youtube_ti.models.playlist import Playlist
from youtube_ti.models.playlist_content_details import PlaylistContentDetails
from youtube_ti.models.playlist_image import PlaylistImage
from youtube_ti.models.playlist_image_list_response import PlaylistImageListResponse
from youtube_ti.models.playlist_image_snippet import PlaylistImageSnippet
from youtube_ti.models.playlist_item import PlaylistItem
from youtube_ti.models.playlist_item_content_details import PlaylistItemContentDetails
from youtube_ti.models.playlist_item_list_response import PlaylistItemListResponse
from youtube_ti.models.playlist_item_snippet import PlaylistItemSnippet
from youtube_ti.models.playlist_item_status import PlaylistItemStatus
from youtube_ti.models.playlist_list_response import PlaylistListResponse
from youtube_ti.models.playlist_localization import PlaylistLocalization
from youtube_ti.models.playlist_player import PlaylistPlayer
from youtube_ti.models.playlist_snippet import PlaylistSnippet
from youtube_ti.models.playlist_status import PlaylistStatus
from youtube_ti.models.property_value import PropertyValue
from youtube_ti.models.related_entity import RelatedEntity
from youtube_ti.models.resource_id import ResourceId
from youtube_ti.models.search_list_response import SearchListResponse
from youtube_ti.models.search_result import SearchResult
from youtube_ti.models.search_result_snippet import SearchResultSnippet
from youtube_ti.models.subscription import Subscription
from youtube_ti.models.subscription_content_details import SubscriptionContentDetails
from youtube_ti.models.subscription_list_response import SubscriptionListResponse
from youtube_ti.models.subscription_snippet import SubscriptionSnippet
from youtube_ti.models.subscription_subscriber_snippet import SubscriptionSubscriberSnippet
from youtube_ti.models.super_chat_event import SuperChatEvent
from youtube_ti.models.super_chat_event_list_response import SuperChatEventListResponse
from youtube_ti.models.super_chat_event_snippet import SuperChatEventSnippet
from youtube_ti.models.super_sticker_metadata import SuperStickerMetadata
from youtube_ti.models.test_item import TestItem
from youtube_ti.models.third_party_link import ThirdPartyLink
from youtube_ti.models.third_party_link_list_response import ThirdPartyLinkListResponse
from youtube_ti.models.third_party_link_snippet import ThirdPartyLinkSnippet
from youtube_ti.models.third_party_link_status import ThirdPartyLinkStatus
from youtube_ti.models.thumbnail import Thumbnail
from youtube_ti.models.thumbnail_details import ThumbnailDetails
from youtube_ti.models.thumbnail_set_response import ThumbnailSetResponse
from youtube_ti.models.video import Video
from youtube_ti.models.video_abuse_report import VideoAbuseReport
from youtube_ti.models.video_abuse_report_reason import VideoAbuseReportReason
from youtube_ti.models.video_abuse_report_reason_list_response import VideoAbuseReportReasonListResponse
from youtube_ti.models.video_abuse_report_reason_snippet import VideoAbuseReportReasonSnippet
from youtube_ti.models.video_abuse_report_secondary_reason import VideoAbuseReportSecondaryReason
from youtube_ti.models.video_age_gating import VideoAgeGating
from youtube_ti.models.video_category import VideoCategory
from youtube_ti.models.video_category_list_response import VideoCategoryListResponse
from youtube_ti.models.video_category_snippet import VideoCategorySnippet
from youtube_ti.models.video_content_details import VideoContentDetails
from youtube_ti.models.video_content_details_region_restriction import VideoContentDetailsRegionRestriction
from youtube_ti.models.video_file_details import VideoFileDetails
from youtube_ti.models.video_file_details_audio_stream import VideoFileDetailsAudioStream
from youtube_ti.models.video_file_details_video_stream import VideoFileDetailsVideoStream
from youtube_ti.models.video_get_rating_response import VideoGetRatingResponse
from youtube_ti.models.video_list_response import VideoListResponse
from youtube_ti.models.video_live_streaming_details import VideoLiveStreamingDetails
from youtube_ti.models.video_localization import VideoLocalization
from youtube_ti.models.video_monetization_details import VideoMonetizationDetails
from youtube_ti.models.video_paid_product_placement_details import VideoPaidProductPlacementDetails
from youtube_ti.models.video_player import VideoPlayer
from youtube_ti.models.video_processing_details import VideoProcessingDetails
from youtube_ti.models.video_processing_details_processing_progress import VideoProcessingDetailsProcessingProgress
from youtube_ti.models.video_rating import VideoRating
from youtube_ti.models.video_recording_details import VideoRecordingDetails
from youtube_ti.models.video_snippet import VideoSnippet
from youtube_ti.models.video_statistics import VideoStatistics
from youtube_ti.models.video_status import VideoStatus
from youtube_ti.models.video_suggestions import VideoSuggestions
from youtube_ti.models.video_suggestions_tag_suggestion import VideoSuggestionsTagSuggestion
from youtube_ti.models.video_topic_details import VideoTopicDetails
from youtube_ti.models.video_trainability import VideoTrainability
from youtube_ti.models.watch_settings import WatchSettings
