# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.live_chat_ban import LiveChatBan

class TestLiveChatBan(unittest.TestCase):
    """LiveChatBan unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LiveChatBan:
        """Test LiveChatBan
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LiveChatBan`
        """
        model = LiveChatBan()
        if include_optional:
            return LiveChatBan(
                etag = '',
                id = '',
                kind = 'youtube#liveChatBan',
                snippet = youtube_ti.models.live_chat_ban_snippet.LiveChatBanSnippet(
                    ban_duration_seconds = '', 
                    banned_user_details = youtube_ti.models.channel_profile_details.ChannelProfileDetails(
                        channel_id = '', 
                        channel_url = '', 
                        display_name = '', 
                        profile_image_url = '', ), 
                    live_chat_id = '', 
                    type = 'liveChatBanTypeUnspecified', )
            )
        else:
            return LiveChatBan(
        )
        """

    def testLiveChatBan(self):
        """Test LiveChatBan"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
