# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.channel_section_list_response import ChannelSectionListResponse

class TestChannelSectionListResponse(unittest.TestCase):
    """ChannelSectionListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChannelSectionListResponse:
        """Test ChannelSectionListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChannelSectionListResponse`
        """
        model = ChannelSectionListResponse()
        if include_optional:
            return ChannelSectionListResponse(
                etag = '',
                event_id = '',
                items = [
                    youtube_ti.models.channel_section.ChannelSection(
                        content_details = youtube_ti.models.channel_section_content_details.ChannelSectionContentDetails(
                            channels = [
                                ''
                                ], 
                            playlists = [
                                ''
                                ], ), 
                        etag = '', 
                        id = '', 
                        kind = 'youtube#channelSection', 
                        localizations = youtube_ti.models.localizations.localizations(), 
                        snippet = youtube_ti.models.channel_section_snippet.ChannelSectionSnippet(
                            channel_id = '', 
                            default_language = '', 
                            localized = youtube_ti.models.channel_section_localization.ChannelSectionLocalization(
                                title = '', ), 
                            position = 56, 
                            style = 'channelsectionStyleUnspecified', 
                            title = '', 
                            type = 'channelsectionTypeUndefined', ), 
                        targeting = youtube_ti.models.channel_section_targeting.ChannelSectionTargeting(
                            countries = [
                                ''
                                ], 
                            languages = [
                                ''
                                ], 
                            regions = [
                                ''
                                ], ), )
                    ],
                kind = 'youtube#channelSectionListResponse',
                visitor_id = ''
            )
        else:
            return ChannelSectionListResponse(
        )
        """

    def testChannelSectionListResponse(self):
        """Test ChannelSectionListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
